@@ -17,4 +17,5 @@ class MidTest(testing.FunctionalTestCase):
     def test_evaluation_C1(self):
         excel_value = self.evaluator.get_cell_value('Sheet1!C1')
         value = self.evaluator.evaluate('Sheet1!C1')
-        self.assertEqual(excel_value, value)
+        # needs to use Text.__eq__ due to equating '' with None
+        self.assertTrue(excel_value == value)
