@@ -27,8 +27,9 @@ class EvaluatorContext(ast_nodes.EvalContext):
             raise RuntimeError(
                 f'Cycle detected for {addr}:\n- ' + '\n- '.join(self.seen))
         self.seen.append(addr)
+        self.set_sheet(sheet=addr.split("!")[0])
 
-        return self.evaluator.evaluate(addr, None)
+        return self.evaluator.evaluate(addr, self)
 
 
 class Evaluator:
